@@ -1,3 +1,4 @@
+
 """
 TroveFM is an online store and headless CMS.
 
@@ -22,6 +23,7 @@ Contact: brian.farrell@me.com
 
 from fastapi import APIRouter
 
+from trove_fm.app.api.routes.company import router as company_router
 from trove_fm.app.api.routes.ping import router as ping_router
 from trove_fm.app.api.routes.person import router as person_router
 
@@ -31,4 +33,5 @@ router = APIRouter()
 # The order that these routes are added here will be reflected in the order that they are
 # displayed in the API documentation at the /docs/ endpoint.
 router.include_router(ping_router, tags=["ping"])
+router.include_router(company_router, prefix="/company", tags=["company"])
 router.include_router(person_router, prefix="/person", tags=["person"])
