@@ -1,3 +1,4 @@
+
 """
 TroveFM is an online store and headless CMS.
 
@@ -39,7 +40,7 @@ class DateTimeModelMixin(BaseModel):
 
     @validator("created_at", "updated_at", pre=True)
     def default_datetime(cls, value: datetime) -> datetime:
-        return value or datetime.datetime.now()
+        return value or datetime.now()
 
 
 class IDModelMixin(BaseModel):
